==> kubernetes-model-batch-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1beta1/CronJobStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CronJobStatusBuilder extends io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatusFluentImpl<io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatus,io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatusBuilder>{
  public CronJobStatusBuilder() {
    this(false);
  }
  public CronJobStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new CronJobStatus(), validationEnabled);
  }
  public CronJobStatusBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CronJobStatusBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CronJobStatus(), validationEnabled);
  }
  public CronJobStatusBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatus instance) {
    this(fluent, instance, false);
  }
  public CronJobStatusBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withActive(instance.getActive()); 
    fluent.withLastScheduleTime(instance.getLastScheduleTime()); 
    fluent.withLastSuccessfulTime(instance.getLastSuccessfulTime()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CronJobStatusBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatus instance) {
    this(instance,false);
  }
  public CronJobStatusBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withActive(instance.getActive()); 
    this.withLastScheduleTime(instance.getLastScheduleTime()); 
    this.withLastSuccessfulTime(instance.getLastSuccessfulTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobStatus build() {
    CronJobStatus buildable = new CronJobStatus(fluent.getActive(),fluent.getLastScheduleTime(),fluent.getLastSuccessfulTime());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CronJobStatusBuilder that = (CronJobStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-batch-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1beta1/CronJobStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CronJobStatusBuilder extends CronJobStatusFluentImpl<CronJobStatusBuilder> implements VisitableBuilder<CronJobStatus,CronJobStatusBuilder>{
  public CronJobStatusBuilder() {
    this(false);
  }
  public CronJobStatusBuilder(Boolean validationEnabled) {
    this(new CronJobStatus(), validationEnabled);
  }
  public CronJobStatusBuilder(CronJobStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CronJobStatusBuilder(CronJobStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CronJobStatus(), validationEnabled);
  }
  public CronJobStatusBuilder(CronJobStatusFluent<?> fluent,CronJobStatus instance) {
    this(fluent, instance, false);
  }
  public CronJobStatusBuilder(CronJobStatusFluent<?> fluent,CronJobStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withActive(instance.getActive()); 
    fluent.withLastScheduleTime(instance.getLastScheduleTime()); 
    fluent.withLastSuccessfulTime(instance.getLastSuccessfulTime()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CronJobStatusBuilder(CronJobStatus instance) {
    this(instance,false);
  }
  public CronJobStatusBuilder(CronJobStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withActive(instance.getActive()); 
    this.withLastScheduleTime(instance.getLastScheduleTime()); 
    this.withLastSuccessfulTime(instance.getLastSuccessfulTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CronJobStatusFluent<?> fluent;
  Boolean validationEnabled;
  public CronJobStatus build() {
    CronJobStatus buildable = new CronJobStatus(fluent.getActive(),fluent.getLastScheduleTime(),fluent.getLastSuccessfulTime());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
